@@ -6,7 +6,10 @@ from pytorch_lightning import LightningModule, Trainer
 from pytorch_lightning.callbacks import Callback
 from pytorch_lightning.utilities import rank_zero_info
 
+from pl_bolts.utils.stability import under_review
 
+
+@under_review()
 class PrintTableMetricsCallback(Callback):
     """Prints a table with the metrics in columns on every epoch end.
 
@@ -35,12 +38,13 @@ class PrintTableMetricsCallback(Callback):
     def __init__(self) -> None:
         self.metrics: List = []
 
-    def on_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+    def on_train_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
         metrics_dict = copy.copy(trainer.callback_metrics)
         self.metrics.append(metrics_dict)
         rank_zero_info(dicts_to_table(self.metrics))
 
 
+@under_review()
 def dicts_to_table(
     dicts: List[Dict],
     keys: Optional[List[str]] = None,
