@@ -23,7 +23,10 @@ if _SPARSEML_AVAILABLE:
     from sparseml.pytorch.optim import ScheduledModifierManager
     from sparseml.pytorch.utils import ModuleExporter
 
+from pl_bolts.utils.stability import under_review
 
+
+@under_review()
 class SparseMLCallback(Callback):
     """Enables SparseML aware training. Requires a recipe to run during training.
 
@@ -37,7 +40,7 @@ class SparseMLCallback(Callback):
             if not _PL_GREATER_EQUAL_1_4_5:
                 raise MisconfigurationException("SparseML requires PyTorch Lightning 1.4.5 or greater.")
             if not _TORCH_MAX_VERSION_SPARSEML:
-                raise MisconfigurationException("SparseML requires PyTorch version lower than 1.10.0.")
+                raise MisconfigurationException("SparseML requires PyTorch version lower than 1.11.0.")
             raise MisconfigurationException("SparseML has not be installed, install with pip install sparseml")
         self.manager = ScheduledModifierManager.from_yaml(recipe_path)
 
@@ -48,35 +51,13 @@ class SparseMLCallback(Callback):
             raise MisconfigurationException("SparseML only supports training with one optimizer.")
         optimizer = optimizer[0]
         optimizer = self.manager.modify(
-            pl_module, optimizer, steps_per_epoch=self._num_training_steps_per_epoch(trainer), epoch=0
+            pl_module, optimizer, steps_per_epoch=trainer.estimated_stepping_batches, epoch=0
         )
         trainer.optimizers = [optimizer]
 
     def on_fit_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
         self.manager.finalize(pl_module)
 
-    def _num_training_steps_per_epoch(self, trainer: Trainer) -> int:
-        """Total training steps inferred from the datamodule and devices."""
-        if isinstance(trainer.limit_train_batches, int) and trainer.limit_train_batches != 0:
-            dataset_size = trainer.limit_train_batches
-        elif isinstance(trainer.limit_train_batches, float):
-            # limit_train_batches is a percentage of batches
-            dataset_size = len(trainer.datamodule.train_dataloader())
-            dataset_size = int(dataset_size * trainer.limit_train_batches)
-        else:
-            dataset_size = len(trainer.datamodule.train_dataloader())
-
-        num_devices = max(1, trainer.num_gpus, trainer.num_processes)
-        if trainer.tpu_cores:
-            num_devices = max(num_devices, trainer.tpu_cores)
-
-        effective_batch_size = trainer.accumulate_grad_batches * num_devices
-        max_estimated_steps = dataset_size // effective_batch_size
-
-        if trainer.max_steps and trainer.max_steps < max_estimated_steps:
-            return trainer.max_steps
-        return max_estimated_steps
-
     @staticmethod
     def export_to_sparse_onnx(
         model: LightningModule, output_dir: str, sample_batch: Optional[torch.Tensor] = None, **export_kwargs: Any
