@@ -7,6 +7,7 @@ from pytorch_lightning.callbacks import Callback
 from torch import Tensor
 
 from pl_bolts.utils import _TORCHVISION_AVAILABLE
+from pl_bolts.utils.stability import under_review
 from pl_bolts.utils.warnings import warn_missing_pkg
 
 if _TORCHVISION_AVAILABLE:
@@ -15,6 +16,7 @@ else:  # pragma: no cover
     warn_missing_pkg("torchvision")
 
 
+@under_review()
 class LatentDimInterpolator(Callback):
     """Interpolates the latent space for a model by setting all dims to zero and stepping through the first two
     dims increasing one unit at a time.
@@ -57,7 +59,7 @@ class LatentDimInterpolator(Callback):
         self.normalize = normalize
         self.steps = steps
 
-    def on_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
+    def on_train_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
         if (trainer.current_epoch + 1) % self.interpolate_epoch_interval == 0:
             images = self.interpolate_latent_space(pl_module, latent_dim=pl_module.hparams.latent_dim)
             images = torch.cat(images, dim=0)
