@@ -8,6 +8,7 @@ import torch
 from torch.utils.data import IterableDataset
 
 from pl_bolts.utils import _GYM_AVAILABLE
+from pl_bolts.utils.stability import under_review
 from pl_bolts.utils.warnings import warn_missing_pkg
 
 try:
@@ -23,6 +24,7 @@ except ImportError:
 Experience = namedtuple("Experience", field_names=["state", "action", "reward", "done", "new_state"])
 
 
+@under_review()
 class ExperienceSourceDataset(IterableDataset):
     """Basic experience source dataset.
 
@@ -39,6 +41,7 @@ class ExperienceSourceDataset(IterableDataset):
 
 
 # Experience Sources
+@under_review()
 class BaseExperienceSource(ABC):
     """Simplest form of the experience source."""
 
@@ -56,6 +59,7 @@ class BaseExperienceSource(ABC):
         raise NotImplementedError("ExperienceSource has no stepper method implemented")
 
 
+@under_review()
 class ExperienceSource(BaseExperienceSource):
     """Experience source class handling single and multiple environment steps."""
 
@@ -231,6 +235,7 @@ class ExperienceSource(BaseExperienceSource):
         return res
 
 
+@under_review()
 class DiscountedExperienceSource(ExperienceSource):
     """Outputs experiences with a discounted reward over N steps."""
 
