@@ -1,21 +1,17 @@
-import gzip
 import hashlib
 import os
 import shutil
-import sys
-import tarfile
 import tempfile
-import zipfile
 from contextlib import contextmanager
 
 import numpy as np
 import torch
 
+from pl_bolts.datasets.utils import extract_archive
 from pl_bolts.utils import _TORCHVISION_AVAILABLE
+from pl_bolts.utils.stability import under_review
 from pl_bolts.utils.warnings import warn_missing_pkg
 
-PY3 = sys.version_info[0] == 3
-
 if _TORCHVISION_AVAILABLE:
     from torchvision.datasets import ImageNet
     from torchvision.datasets.imagenet import load_meta_file
@@ -24,6 +20,7 @@ else:  # pragma: no cover
     ImageNet = object
 
 
+@under_review()
 class UnlabeledImagenet(ImageNet):
     """Official train set gets split into train, val. (using nb_imgs_per_val_class for each class). Official
     validation becomes test set.
@@ -158,6 +155,7 @@ class UnlabeledImagenet(ImageNet):
         print(f"meta.bin generated at {devkit_dir}/meta.bin")
 
 
+@under_review()
 def _verify_archive(root, file, md5):
     if not _check_integrity(os.path.join(root, file), md5):
         raise RuntimeError(
@@ -166,6 +164,7 @@ def _verify_archive(root, file, md5):
         )
 
 
+@under_review()
 def _check_integrity(fpath, md5=None):
     if not os.path.isfile(fpath):
         return False
@@ -174,10 +173,12 @@ def _check_integrity(fpath, md5=None):
     return _check_md5(fpath, md5)
 
 
+@under_review()
 def _check_md5(fpath, md5, **kwargs):
     return md5 == _calculate_md5(fpath, **kwargs)
 
 
+@under_review()
 def _calculate_md5(fpath, chunk_size=1024 * 1024):
     md5 = hashlib.md5()
     with open(fpath, "rb") as f:
@@ -186,6 +187,7 @@ def _calculate_md5(fpath, chunk_size=1024 * 1024):
     return md5.hexdigest()
 
 
+@under_review()
 def parse_devkit_archive(root, file=None):
     """Parse the devkit archive of the ImageNet2012 classification dataset and save the meta information in a
     binary file.
@@ -240,53 +242,3 @@ def parse_devkit_archive(root, file=None):
         META_FILE = "meta.bin"
 
         torch.save((wnid_to_classes, val_wnids), os.path.join(root, META_FILE))
-
-
-def extract_archive(from_path, to_path=None, remove_finished=False):
-    if to_path is None:
-        to_path = os.path.dirname(from_path)
-
-    PY3 = sys.version_info[0] == 3
-
-    if _is_tar(from_path):
-        with tarfile.open(from_path, "r") as tar:
-            tar.extractall(path=to_path)
-    elif _is_targz(from_path):
-        with tarfile.open(from_path, "r:gz") as tar:
-            tar.extractall(path=to_path)
-    elif _is_tarxz(from_path) and PY3:
-        # .tar.xz archive only supported in Python 3.x
-        with tarfile.open(from_path, "r:xz") as tar:
-            tar.extractall(path=to_path)
-    elif _is_gzip(from_path):
-        to_path = os.path.join(to_path, os.path.splitext(os.path.basename(from_path))[0])
-        with open(to_path, "wb") as out_f, gzip.GzipFile(from_path) as zip_f:
-            out_f.write(zip_f.read())
-    elif _is_zip(from_path):
-        with zipfile.ZipFile(from_path, "r") as z:
-            z.extractall(to_path)
-    else:
-        raise ValueError(f"Extraction of {from_path} not supported")
-
-    if remove_finished:
-        os.remove(from_path)
-
-
-def _is_targz(filename):
-    return filename.endswith(".tar.gz")
-
-
-def _is_tarxz(filename):
-    return filename.endswith(".tar.xz")
-
-
-def _is_gzip(filename):
-    return filename.endswith(".gz") and not filename.endswith(".tar.gz")
-
-
-def _is_tar(filename):
-    return filename.endswith(".tar")
-
-
-def _is_zip(filename):
-    return filename.endswith(".zip")
