@@ -4,6 +4,7 @@ import numpy as np
 
 from pl_bolts.datasets.sr_dataset_mixin import SRDatasetMixin
 from pl_bolts.utils import _PIL_AVAILABLE, _TORCHVISION_AVAILABLE
+from pl_bolts.utils.stability import under_review
 from pl_bolts.utils.warnings import warn_missing_pkg
 
 if _PIL_AVAILABLE:
@@ -18,6 +19,7 @@ else:  # pragma: no cover
     STL10 = object
 
 
+@under_review()
 class SRSTL10(SRDatasetMixin, STL10):
     """STL10 dataset that can be used to train Super Resolution models.
 
