@@ -16,8 +16,8 @@ def accuracy(preds, labels):
     return acc
 
 
-def precision_at_k(output, target, top_k=(1, )):
-    """Computes the accuracy over the k top predictions for the specified values of k"""
+def precision_at_k(output, target, top_k=(1,)):
+    """Computes the accuracy over the k top predictions for the specified values of k."""
     with torch.no_grad():
         maxk = max(top_k)
         batch_size = target.size(0)
