@@ -15,6 +15,7 @@ from pl_bolts.datamodules import ExperienceSourceDataset
 from pl_bolts.models.rl.common.agents import ActorCriticAgent
 from pl_bolts.models.rl.common.networks import ActorCriticMLP
 from pl_bolts.utils import _GYM_AVAILABLE
+from pl_bolts.utils.stability import under_review
 from pl_bolts.utils.warnings import warn_missing_pkg
 
 if _GYM_AVAILABLE:
@@ -23,6 +24,7 @@ else:  # pragma: no cover
     warn_missing_pkg("gym")
 
 
+@under_review()
 class AdvantageActorCritic(LightningModule):
     """PyTorch Lightning implementation of `Advantage Actor Critic <https://arxiv.org/abs/1602.01783v2>`_.
 
@@ -294,6 +296,7 @@ class AdvantageActorCritic(LightningModule):
         return arg_parser
 
 
+@under_review()
 def cli_main() -> None:
     parser = ArgumentParser(add_help=False)
 
