@@ -12,8 +12,10 @@ from pl_bolts.datamodules import ExperienceSourceDataset
 from pl_bolts.losses.rl import per_dqn_loss
 from pl_bolts.models.rl.common.memory import Experience, PERBuffer
 from pl_bolts.models.rl.dqn_model import DQN
+from pl_bolts.utils.stability import under_review
 
 
+@under_review()
 class PERDQN(DQN):
     """PyTorch Lightning implementation of `DQN With Prioritized Experience Replay`_.
 
@@ -110,7 +112,7 @@ class PERDQN(DQN):
         # calculates training loss
         loss, batch_weights = per_dqn_loss(samples, weights, self.net, self.target_net, self.gamma)
 
-        if self._use_dp_or_ddp2(self.trainer):
+        if self._use_dp(self.trainer):
             loss = loss.unsqueeze(0)
 
         # update priorities in buffer
@@ -145,6 +147,7 @@ class PERDQN(DQN):
         return DataLoader(dataset=self.dataset, batch_size=self.batch_size)
 
 
+@under_review()
 def cli_main():
     parser = argparse.ArgumentParser(add_help=False)
 
