@@ -16,6 +16,7 @@ from pl_bolts.models.rl.common.agents import SoftActorCriticAgent
 from pl_bolts.models.rl.common.memory import MultiStepBuffer
 from pl_bolts.models.rl.common.networks import MLP, ContinuousMLP
 from pl_bolts.utils import _GYM_AVAILABLE
+from pl_bolts.utils.stability import under_review
 from pl_bolts.utils.warnings import warn_missing_pkg
 
 if _GYM_AVAILABLE:
@@ -25,6 +26,7 @@ else:  # pragma: no cover
     Env = object
 
 
+@under_review()
 class SAC(LightningModule):
     def __init__(
         self,
@@ -384,6 +386,7 @@ class SAC(LightningModule):
         return arg_parser
 
 
+@under_review()
 def cli_main():
     parser = argparse.ArgumentParser(add_help=False)
 
