@@ -5,7 +5,10 @@ import torch
 from torch import nn
 from torch.nn import functional as F
 
+from pl_bolts.utils.stability import under_review
 
+
+@under_review()
 class AMDIMEncoder(nn.Module):
     def __init__(
         self,
@@ -146,6 +149,7 @@ class AMDIMEncoder(nn.Module):
         return r1, r5, r7
 
 
+@under_review()
 class Conv3x3(nn.Module):
     def __init__(self, n_in, n_out, n_kern, n_stride, n_pad, use_bn=True, pad_mode="constant"):
         super().__init__()
@@ -169,6 +173,7 @@ class Conv3x3(nn.Module):
         return out
 
 
+@under_review()
 class ConvResBlock(nn.Module):
     def __init__(self, n_in, n_out, width, stride, pad, depth, use_bn):
         super().__init__()
@@ -188,6 +193,7 @@ class ConvResBlock(nn.Module):
         return x_out
 
 
+@under_review()
 class ConvResNxN(nn.Module):
     def __init__(self, n_in, n_out, width, stride, pad, use_bn=False):
         super().__init__()
@@ -232,6 +238,7 @@ class ConvResNxN(nn.Module):
         return h23
 
 
+@under_review()
 class MaybeBatchNorm2d(nn.Module):
     def __init__(self, n_ftr, affine, use_bn):
         super().__init__()
@@ -244,6 +251,7 @@ class MaybeBatchNorm2d(nn.Module):
         return x
 
 
+@under_review()
 class NopNet(nn.Module):
     def __init__(self, norm_dim=None):
         super().__init__()
@@ -251,12 +259,13 @@ class NopNet(nn.Module):
 
     def forward(self, x):
         if self.norm_dim is not None:
-            x_norms = torch.sum(x ** 2.0, dim=self.norm_dim, keepdim=True)
+            x_norms = torch.sum(x**2.0, dim=self.norm_dim, keepdim=True)
             x_norms = torch.sqrt(x_norms + 1e-6)
             x = x / x_norms
         return x
 
 
+@under_review()
 class FakeRKHSConvNet(nn.Module):
     def __init__(self, n_input, n_output, use_bn=False):
         super().__init__()
