@@ -2,7 +2,10 @@ import math
 
 from pytorch_lightning import Callback
 
+from pl_bolts.utils.stability import under_review
 
+
+@under_review()
 class MocoLRScheduler(Callback):
     def __init__(self, initial_lr=0.03, use_cosine_scheduler=False, schedule=(120, 160), max_epochs=200):
         super().__init__()
@@ -11,7 +14,7 @@ class MocoLRScheduler(Callback):
         self.schedule = schedule
         self.max_epochs = max_epochs
 
-    def on_epoch_start(self, trainer, pl_module):
+    def on_train_epoch_start(self, trainer, pl_module):
         epoch = trainer.current_epoch
         lr = self.lr
 
