@@ -15,8 +15,10 @@ from pl_bolts.transforms.dataset_normalizations import (
     imagenet_normalization,
     stl10_normalization,
 )
+from pl_bolts.utils.stability import under_review
 
 
+@under_review()
 class SyncFunction(torch.autograd.Function):
     @staticmethod
     def forward(ctx, tensor):
@@ -39,6 +41,7 @@ class SyncFunction(torch.autograd.Function):
         return grad_input[idx_from:idx_to]
 
 
+@under_review()
 class Projection(nn.Module):
     def __init__(self, input_dim=2048, hidden_dim=2048, output_dim=128):
         super().__init__()
@@ -58,6 +61,7 @@ class Projection(nn.Module):
         return F.normalize(x, dim=1)
 
 
+@under_review()
 class SimCLR(LightningModule):
     def __init__(
         self,
@@ -300,6 +304,7 @@ class SimCLR(LightningModule):
         return parser
 
 
+@under_review()
 def cli_main():
     from pl_bolts.callbacks.ssl_online import SSLOnlineEvaluator
     from pl_bolts.datamodules import CIFAR10DataModule, ImagenetDataModule, STL10DataModule
@@ -320,7 +325,7 @@ def cli_main():
 
         args.maxpool1 = False
         args.first_conv = True
-        args.input_height = dm.size()[-1]
+        args.input_height = dm.dims[-1]
 
         normalization = stl10_normalization()
 
@@ -339,7 +344,7 @@ def cli_main():
 
         args.maxpool1 = False
         args.first_conv = False
-        args.input_height = dm.size()[-1]
+        args.input_height = dm.dims[-1]
         args.temperature = 0.5
 
         normalization = cifar10_normalization()
@@ -368,7 +373,7 @@ def cli_main():
         dm = ImagenetDataModule(data_dir=args.data_dir, batch_size=args.batch_size, num_workers=args.num_workers)
 
         args.num_samples = dm.num_samples
-        args.input_height = dm.size()[-1]
+        args.input_height = dm.dims[-1]
     else:
         raise NotImplementedError("other datasets have not been implemented till now")
 
