@@ -44,13 +44,13 @@ def cli_main():  # pragma: no cover
         args.num_samples = 0
 
         dm.train_transforms = SwAVFinetuneTransform(
-            normalize=stl10_normalization(), input_height=dm.size()[-1], eval_transform=False
+            normalize=stl10_normalization(), input_height=dm.dims[-1], eval_transform=False
         )
         dm.val_transforms = SwAVFinetuneTransform(
-            normalize=stl10_normalization(), input_height=dm.size()[-1], eval_transform=True
+            normalize=stl10_normalization(), input_height=dm.dims[-1], eval_transform=True
         )
         dm.test_transforms = SwAVFinetuneTransform(
-            normalize=stl10_normalization(), input_height=dm.size()[-1], eval_transform=True
+            normalize=stl10_normalization(), input_height=dm.dims[-1], eval_transform=True
         )
 
         args.maxpool1 = False
@@ -59,14 +59,14 @@ def cli_main():  # pragma: no cover
         dm = ImagenetDataModule(data_dir=args.data_dir, batch_size=args.batch_size, num_workers=args.num_workers)
 
         dm.train_transforms = SwAVFinetuneTransform(
-            normalize=imagenet_normalization(), input_height=dm.size()[-1], eval_transform=False
+            normalize=imagenet_normalization(), input_height=dm.dims[-1], eval_transform=False
         )
         dm.val_transforms = SwAVFinetuneTransform(
-            normalize=imagenet_normalization(), input_height=dm.size()[-1], eval_transform=True
+            normalize=imagenet_normalization(), input_height=dm.dims[-1], eval_transform=True
         )
 
         dm.test_transforms = SwAVFinetuneTransform(
-            normalize=imagenet_normalization(), input_height=dm.size()[-1], eval_transform=True
+            normalize=imagenet_normalization(), input_height=dm.dims[-1], eval_transform=True
         )
 
         args.num_samples = 1
